<?php

namespace App\Http\Controllers\Api\V1\Auth\Customer;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\CustomerLoginRequest;
use App\Models\Customer;
use App\Models\CustomerPasswordReset;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;

class CustomerResetPasswordController extends Controller
{

    /**
     * @throws \Exception
     */
    public function sendResetCodeEmail(Request $request)
    {
        $validationRule = [
            'type' => 'required|in:sms,email',
            'sender' => function ($attribute, $value, $fail) use ($request) {
                if ($request->type === 'sms') {
                    if (empty($value)) {
                        $fail(trans('api.sender_sms_type_required'));
                    }
                } else {
                    if (empty($value)) {
                        $fail(trans('api.sender_sms_type_required'));
                    } elseif (!filter_var($value, FILTER_VALIDATE_EMAIL)) {
                        $fail(trans('api.sender_email_must_be_valid_email'));
                    }
                }
            },
        ];

        $validator = Validator::make($request->all(), $validationRule);
        if ($validator->fails()) {
            return responseJson(false, $validator->errors()->first());
        }

        try {
            $customer = Customer::where('email', $request->sender)->first();

            if (!$customer) {
                return responseJson(false, trans('api.customer_not_found'));
            }

            CustomerPasswordReset::where('sender', $customer->email)->delete();
            $code = verificationCode(6);
            $password = new CustomerPasswordReset();
            $password->type = $request->type;
            $password->sender = $customer->email;
            $password->token = $code;
            $password->created_at = Carbon::now();
            $password->save();

            $userIpInfo = getIpInfo();
            $userBrowserInfo = osBrowser();
            sendEmail($customer, 'PASS_RESET_CODE', [
                'code' => $code,
                'operating_system' => @$userBrowserInfo['os_platform'],
                'browser' => @$userBrowserInfo['browser'],
                'ip' => @$userIpInfo['ip'],
                'time' => @$userIpInfo['time']
            ]);

            $email = $customer->email;

            return responseJson(true, trans('api.password_reset_email_sent_successfully', ['email' => $email]), ['email' => $email]);
        } catch (\Exception $e) {
            Log::error($e);
            return responseJson(false, trans('api.something_wrong'));
        }
    }

    public function verifyCode(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'code' => 'required',
            'sender' => 'required|email'
        ]);

        if ($validator->fails()) {
            return responseJson(422, 'failed', $validator->errors()->all());
        }

        try {

            $code = $request->code;

            if (CustomerPasswordReset::where('token', $code)->where('sender', $request->sender)->count() != 1) {
                return responseJson(false, trans('api.invalid_code'));
            }

            $data = [
                'token' => $code,
                'sender' => $request->sender,
            ];

            return responseJson(true, trans('api.verify_success'), $data);
        } catch (\Exception $e) {
            Log::error($e);
            return responseJson(false, trans('api.something_wrong'));
        }
    }

    /**
     * @throws \Exception
     */
    public function reset(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'code' => 'required',
            'sender' => 'required|email',
            'password' => ['required', 'confirmed', 'min:6'],
        ]);

        if ($validator->fails()) {
            return responseJson(false, $validator->errors()->all());
        }

        try {
            $reset = CustomerPasswordReset::where('token', $request->code)->where('sender', $request->sender)->orderBy('created_at', 'desc')->first();
            if (!$reset) {
                return responseJson(false, trans('api.invalid_verification_code'));
            }

            $customer = Customer::where('email', $reset->sender)->first();
            $customer->password = bcrypt($request->password);
            $customer->save();

            $userIpInfo = getIpInfo();
            $userBrowser = osBrowser();
            sendEmail($customer, 'PASS_RESET_DONE', [
                'operating_system' => @$userBrowser['os_platform'],
                'browser' => @$userBrowser['browser'],
                'ip' => @$userIpInfo['ip'],
                'time' => @$userIpInfo['time']
            ]);

            return responseJson(true, trans('api.password_changes_successfully'));
        } catch (\Exception $e) {
            Log::error($e);
            return responseJson(false, trans('api.something_wrong'));
        }
    }
}
