<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\CitiesDataResource;
use App\Http\Resources\CountriesDataResource;
use App\Models\City;
use App\Models\Country;
use Illuminate\Support\Facades\Crypt;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;

class BasicController extends Controller
{
    public function unauthenticated()
    {
        try {
            return responseJson(false, trans('api.unauthorized'));
        } catch (\Exception $e) {
            Log::error($e);
            return responseJson(false, trans('api.something_wrong'));
        }
    }

    public function countries()
    {
        try {
            $countries = Country::query()->where('status', 0)->get();
            $data = CountriesDataResource::collection($countries);
            return responseJson(false, trans('api.cities_data'), $data);
        } catch (\Exception $e) {
            Log::error($e);
            return responseJson(false, trans('api.something_wrong'));
        }
    }

    public function cities(Request $request)
    {
        try {
            $decryptText = Crypt::decryptString($request->pr);
            $rules = [
                'pr' => ['required', 'exists:countries,id'],
            ];

            $validator = Validator::make(['pr' => $decryptText], $rules);

            if ($validator->fails()) {
                return responseJson(422, 'failed', $validator->errors()->all());
            }

            $cities = City::query()->where('status', 0)->get();
            $data = CitiesDataResource::collection($cities);
            return responseJson(false, trans('api.cities_data'), $data);
        } catch (\Exception $e) {
            Log::error($e);
            return responseJson(false, trans('api.something_wrong'));
        }
    }
}
