<?php

namespace App\Http\Controllers\Api\V1\Customer;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\ChangePasswordRequest;
use App\Http\Requests\Api\CustomerUpdateProfileRequest;
use App\Http\Resources\CustomerDataResource;
use App\Models\City;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;

class CustomerController extends Controller
{
    protected $customer;

    public function __construct()
    {
        $this->customer = auth()->guard('customer_api')->user();
    }

    public function profile()
    {
        try {
            $data = new CustomerDataResource($this->customer);
            return responseJson(true, trans('api.customer_data'), $data);
        } catch (\Exception $e) {
            Log::error($e);
            return responseJson(false, trans('api.something_wrong'));
        }
    }

    public function changePassword(ChangePasswordRequest $request)
    {
        try {
            if (Hash::check($request->current_password, $this->customer->password)) {
                $password = Hash::make($request->password);
                $this->customer->password = $password;
                $this->customer->save();
                return responseJson(true, trans('api.password_changes_successfully'));
            } else {
                return responseJson(false, trans("api.password_doesnt_match"));
            }

        } catch (\Exception $e) {
            Log::error($e);
            return responseJson(false, trans('api.something_wrong'));
        }
    }

    public function updateProfile(CustomerUpdateProfileRequest $request)
    {
        DB::beginTransaction();
        try {
            $city_request = $request->input('city');
            $city_id = City::query()->where('id', $city_request)->first();

            if (!$city_id) {
                return responseJson(false, trans('Unable to find City'));
            }

            $image = null;
            if ($request->hasFile('image')) {
                try {
                    $image = uploadImage($request->image, imagePath()['profile']['customer']['path'], imagePath()['profile']['customer']['size'], true);
                } catch (\Exception $e) {
                    return responseJson(false, trans('api.image_not_uploaded'));
                }
            }

            $customer_params = [
                'name' => $request->input('name'),
                'email' => $request->input('email'),
                'mobile' => $request->input('mobile'),
                'address' => $request->input('address'),
                'city_id' => $request->input('city'),
                'gender' => $request->input('gender'),
                'image' => $image,
            ];

            $this->customer->update($customer_params);

            DB::commit();

            return responseJson(true, trans('api.profile_updated_successfully'));
        } catch (\Exception $e) {
            DB::rollBack();
            Log::error('Error while Registering a user account. Input params : ' . json_encode($request->all()));
            Log::error($e);
            return responseJson(false, trans('api.something_wrong'));
        }
    }
}
