<?php

namespace App\Http\Controllers\Api\V1\Vendor;

use App\Http\Controllers\Controller;
use App\Http\Resources\CarsResource;
use App\Http\Resources\CategoriesResource;
use App\Http\Resources\CitiesDataResource;
use App\Http\Resources\ColorsResource;
use App\Http\Resources\VendorProductsResource;
use App\Models\Car;
use App\Models\Category;
use App\Models\City;
use App\Models\Color;
use App\Models\Product;
use App\Traits\GeneralTrait;
use App\Traits\ImageTraits;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ProductsController extends Controller
{
    use GeneralTrait;
    use ImageTraits;
    public function getVendorProducts()
    {
        try {
            $vendorId = Auth::guard('vendor_api')->user()->id;
            $products = Product::where('vendor_id', $vendorId)->get();

            if ($products->isEmpty()) {
                return $this->returnSuccessMessage('This Vendor didn\'t have any Products', '200');
            } else {
                $productsResource = VendorProductsResource::collection($products);
                return $this->returnData('data', $productsResource, 'Get Vendor Data Success');
            }
        } catch (\Exception $e) {
            return $this->returnError('401', 'Something went wrong');
        }
    }
    public function getCarsList()
    {
        try {
            $cars = Car::get();
            if ($cars->isEmpty()) {
                return $this->returnSuccessMessage('No Cars Found', '200');
            } else {
                $cars = CarsResource::collection($cars);
                return $this->returnData('data', $cars, 'Get Cars List Success');
            }
        } catch (\Exception $e) {
            return $this->returnError('401', 'Something went wrong');
        }
    }
    public function getCategoriesList()
    {
        try {
            $categories = Category::get();
            if ($categories->isEmpty()) {
                return $this->returnSuccessMessage('No Categories Found', '200');
            } else {
                $categories = CategoriesResource::collection($categories);
                return $this->returnData('data', $categories, 'Get Categories List Success');
            }
        } catch (\Exception $e) {
            return $this->returnError('401', 'Something went wrong');
        }
    }
    public function getColorsList()
    {
        try {
            $colors = Color::get();
            if ($colors->isEmpty()) {
                return $this->returnSuccessMessage('No Colors Found', '200');
            } else {
                $colors = ColorsResource::collection($colors);
                return $this->returnData('data', $colors, 'Get Colors List Success');
            }
        } catch (\Exception $e) {
            return $this->returnError('401', 'Something went wrong');
        }
    }
    public function getCitiesList()
    {
        try {
            $cities = City::get();
            if ($cities->isEmpty()) {
                return $this->returnSuccessMessage('No Cities Found', '200');
            } else {
                $cities = CitiesDataResource::collection($cities);
                return $this->returnData('data', $cities, 'Get Cities List Success');
            }
        } catch (\Exception $e) {
            return $this->returnError('401', 'Something went wrong');
        }
    }
    public function storeVendorProducts(Request $request)
    {
        try {
            $vendorId   =   Auth::guard('vendor_api')->user()->id;
            $product = new Product();
            $this->uploadImage($product, 'product',$request,'front_image');
            $product->name        =   $request->name;
            $product->price       =   $request->price;
            $product->notes       =   $request->notes;
            $product->model       =   $request->model;
            $product->model_year  =   $request->model_year;
            $product->km          =   $request->km;
            $product->type        =   $request->type;
            $product->quantity    =   $request->quantity;
            $product->mover       =   $request->mover;
            $product->fuel        =   $request->fuel;
            $product->city_id     =   $request->city_id;
            $product->car_id      =   $request->car_id;
            $product->color_id    =   $request->color_id;
            $product->category_id =   $request->category_id;
            $product->vendor_id   =   $vendorId;
            $product->save();
            $this->multipleImage($product, 'product',$request,'image','App\Models\ProductImage', 'product_id');
            return $this->returnData('data', $product, 'Product Added Successfully');
        } catch (\Exception $e) {
            return $this->returnError('401', 'Something went wrong');
        }
    }
    public function deleteVendorProducts(Request $request)
    {
        try {
            $productId      =   $request->product_id;
            $product        =   Product::findOrFail($productId);
            $product->destroy($product->id);
            return $this->returnSuccessMessage('Product Deleted Successfully', '200');
        } catch (\Exception $e) {
            return $this->returnError('401', 'Something went wrong');
        }
    }



}
