<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\BlogCategory;
use App\Models\Tag;
use App\Traits\ImageTraits;
use Illuminate\Http\Request;

class BlogController extends Controller
{
use ImageTraits;
    protected $data = [
                 'folder' => 'backend.',
                 'var' => 'blog.',
                 'Models' => 'App\Models\Blog',
                 'Model2' => 'App\Models\BlogImage',
                 'folderBlade' => 'blog',
                 'imageName1' => 'front_image',
                 'imageName2' => 'image',
             ];


    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $data = [
             'data' => $this->data['Models']::all(),
         ];
         return view($this->data['folder'] . $this->data['folderBlade'] . '.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data = [
                    'categories'    =>  BlogCategory::all(),
                    'tags'          =>  Tag::all(),
                ];
        return view($this->data['folder'] . $this->data['folderBlade'] . '.create', $data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->data['var'] = new $this->data['Models']();
        $this->uploadImage($this->data['var'], $this->data['folderBlade'],$request,$this->data['imageName1']);
        $this->data['var']->name        =   ['en' => $request->name, 'ar' => $request->name_ar];
        $this->data['var']->notes       =   ['en' => $request->notes, 'ar' => $request->notes_ar];
        $this->data['var']->blog_category_id       =   $request->blog_category_id;
        $this->data['var']->save();
        $this->multipleImage($this->data['var'], $this->data['folderBlade'],$request,$this->data['imageName2'], $this->data['Model2'], 'blog_id');
        $blog = $this->data['Models']::findorfail($this->data['var']->id);
        $blog -> tags()->attach($request->tag_id);
        toastr()->success(trans('custom.add_successful'),trans('custom.success'));
        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data = [
                  'data' => $this->data['Models']::findorfail(decrypt($id)),
                 ];
        return view($this->data['folder'] . $this->data['folderBlade'] . '.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data = [
                    'data' => $this->data['Models']::findorfail(decrypt($id)),
                    'categories'    =>  BlogCategory::all(),
                    'tags'          =>  Tag::all(),
                 ];
        return view($this->data['folder'] . $this->data['folderBlade'] . '.edit', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->data['var']=$this->data['Models']::findorfail(decrypt($id));
        $this->uploadImage($this->data['var'], $this->data['folderBlade'],$request,$this->data['imageName1']);
        $this->data['var']->name        =   ['en' => $request->name, 'ar' => $request->name_ar];
        $this->data['var']->notes       =   ['en' => $request->notes, 'ar' => $request->notes_ar];
        $this->data['var']->status      =   $request->status;
        $this->data['var']->blog_category_id       =   $request->blog_category_id;
        if ($request->image) {
            $this->multipleImage($this->data['var'], $this->data['folderBlade'], $request, $this->data['imageName2'], $this->data['Model2'], 'blog_id');
        }
        $this->data['var'] -> tags()->sync($request->tag_id);
        $this->data['var']->update();
        toastr()->success(trans('custom.updated_successful'),trans('custom.success'));
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $this->data['var']=$this->data['Models']::findorfail(decrypt($id));
        $this->data['var']->destroy(decrypt($id));
        toastr()->error(trans('custom.deleted_successful'),trans('custom.success'));
        return redirect()->back();
    }
    public function removeImage($id)
    {
        $this->data['var']=$this->data['Model2']::findorfail(decrypt($id));
        $this->data['var']->destroy(decrypt($id));
        toastr()->error(trans('custom.deleted_successful'),trans('custom.success'));
        return redirect()->back();
    }
}
