<?php

namespace App\Http\Controllers\Vendor;

use App\Http\Controllers\Controller;
use App\Models\Car;
use App\Models\Category;
use App\Models\City;
use App\Models\Color;
use App\Traits\ImageTraits;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ProductController extends Controller
{
use ImageTraits;
    protected $data = [
                 'folder' => 'vendor.',
                 'var' => 'product.',
                 'Models' => 'App\Models\Product',
                 'imageModels' => 'App\Models\ProductImage',
                 'folderBlade' => 'product',
                 'imageName1' => 'front_image',
                 'imageName2' => 'image',
             ];


    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $data = [
             'data' => $this->data['Models']::where('vendor_id', Auth::guard('vendor')->user()->id)->get(),
         ];
         return view($this->data['folder'] . $this->data['folderBlade'] . '.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data = [
                    'cars'          =>  Car::all(),
                    'categories'    =>  Category::all(),
                    'colors'        =>  Color::all(),
                    'cities'        =>  City::all(),
                ];
        return view($this->data['folder'] . $this->data['folderBlade'] . '.create', $data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->data['var'] = new $this->data['Models']();
        $this->uploadImage($this->data['var'], $this->data['folderBlade'],$request,$this->data['imageName1']);
        $this->data['var']->name        =   $request->name;
        $this->data['var']->price       =   $request->price;
        $this->data['var']->notes       =   $request->notes;
        $this->data['var']->model       =   $request->model;
        $this->data['var']->model_year  =   $request->model_year;
        $this->data['var']->km          =   $request->km;
        $this->data['var']->type        =   $request->type;
        $this->data['var']->quantity    =   $request->quantity;
        $this->data['var']->mover       =   $request->mover;
        $this->data['var']->fuel        =   $request->fuel;
        $this->data['var']->city_id     =   $request->city_id;
        $this->data['var']->car_id      =   $request->car_id;
        $this->data['var']->color_id    =   $request->color_id;
        $this->data['var']->category_id =   $request->category_id;
        $this->data['var']->vendor_id   =   Auth::guard('vendor')->user()->id;
        $this->data['var']->save();
        $this->multipleImage($this->data['var'], $this->data['folderBlade'],$request,$this->data['imageName2'],$this->data['imageModels'], 'product_id');
        toastr()->success(trans('custom.add_successful'),trans('custom.success'));
        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data = [
                  'data' => $this->data['Models']::findorfail(decrypt($id)),
                 ];
        return view($this->data['folder'] . $this->data['folderBlade'] . '.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data = [
                    'data' => $this->data['Models']::findorfail(decrypt($id)),
                    'cars'          =>  Car::all(),
                    'categories'    =>  Category::all(),
                    'colors'        =>  Color::all(),
                    'cities'        =>  City::all(),
                 ];
        return view($this->data['folder'] . $this->data['folderBlade'] . '.edit', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->data['var']=$this->data['Models']::findorfail(decrypt($id));
        $this->uploadImage($this->data['var'], $this->data['folderBlade'],$request,$this->data['imageName1']);
        $this->data['var']->name        =   $request->name;
        $this->data['var']->price       =   $request->price;
        $this->data['var']->notes       =   $request->notes;
        $this->data['var']->model       =   $request->model;
        $this->data['var']->model_year  =   $request->model_year;
        $this->data['var']->km          =   $request->km;
        $this->data['var']->type        =   $request->type;
        $this->data['var']->quantity    =   $request->quantity;
        $this->data['var']->mover       =   $request->mover;
        $this->data['var']->fuel        =   $request->fuel;
        $this->data['var']->city_id     =   $request->city_id;
        $this->data['var']->car_id      =   $request->car_id;
        $this->data['var']->color_id    =   $request->color_id;
        $this->data['var']->category_id =   $request->category_id;
        if ($request->has('image'))
        {
            $this->multipleImage($this->data['var'], $this->data['folderBlade'],$request,$this->data['imageName2'],$this->data['imageModels'], 'product_id');
        }
        $this->data['var']->update();
        toastr()->success(trans('custom.updated_successful'),trans('custom.success'));
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $this->data['var']=$this->data['Models']::findorfail(decrypt($id));
        $this->data['var']->destroy(decrypt($id));
        toastr()->error(trans('custom.deleted_successful'),trans('custom.success'));
        return redirect()->back();
    }
    public function destroyImage($id)
    {
        $this->data['var']=$this->data['imageModels']::findorfail(decrypt($id));
        $this->data['var']->destroy(decrypt($id));
        toastr()->error(trans('custom.deleted_successful'),trans('custom.success'));
        return redirect()->back();
    }
}
