<?php

namespace App\Http\Requests\Api;

use Illuminate\Contracts\Validation\ValidationRule;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;

class CustomerRegistrationRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, ValidationRule|array|string>
     */
    public function rules(): array
    {
        return [
            'name' => ['required', 'max:50'],
            'email' => ['required', 'email', 'max:150', 'unique:customers,email'],
            'image' => ['image', 'mimes:jpg,png,jpeg'],
            'password' => ['required', 'min:6', 'confirmed'],
            'mobile' => ['required', 'unique:customers,mobile'],
            'city' => ['required', 'exists:cities,id'],
            'address' => 'required',
            'gender' => ['required', 'in:0,1'],
            'terms_condition' => ['sometimes', 'required', 'boolean', 'in:1'],
            'device_token' => ['sometimes', 'required'],
            'login_by' => ['sometimes', 'required', 'in:android,ios'],
        ];
    }

    public function failedValidation(Validator $validator)
    {
        throw new HttpResponseException(responseJson(false, trans($validator->errors()->first())));
    }
}
