<?php

namespace App\Http\Requests\Api;

use Illuminate\Contracts\Validation\ValidationRule;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;
use Illuminate\Validation\Rule;

class CustomerUpdateProfileRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, ValidationRule|array|string>
     */
    public function rules(): array
    {
        $customerId = auth()->guard('customer_api')->user()->id;
        return [
            'name' => ['required', 'max:50'],
            'email' => ['required', 'email', 'max:150', Rule::unique('customers')->ignore($customerId)],
            'image' => ['image', 'mimes:jpg,png,jpeg'],
            'mobile' => ['required', Rule::unique('customers')->ignore($customerId)],
            'city' => ['required', 'exists:cities,id'],
            'address' => 'required',
            'gender' => ['required', 'in:0,1']
        ];
    }

    public function failedValidation(Validator $validator)
    {
        throw new HttpResponseException(responseJson(false, trans($validator->errors()->first())));
    }
}
