<?php

namespace App\Listeners;

use App\Events\CustomerLogin;
use App\Events\CustomerLogout;
use App\Events\CustomerRegistered;
use App\Models\Customer;
use Illuminate\Events\Dispatcher;

class CustomerEventSubscriber
{
    /**
     * Handle customer login event.
     *
     * @param CustomerLogin $event
     */
    public function onCustomerLogin(CustomerLogin $event): void
    {
        $this->updateCustomerInfo($event->customer);
    }

    /**
     * Handle customer logout event.
     *
     * @param CustomerLogout $event
     */
    public function onCustomerLogout(CustomerLogout $event): void
    {
        $this->updateCustomerInfo($event->customer);
    }

    /**
     * Handle customer register event.
     *
     * @param CustomerRegistered $event
     */
    public function onCustomerRegistered(CustomerRegistered $event): void
    {
        $this->updateCustomerInfo($event->customer);
    }

    /**
     * Update the customer's last known ip and last login time.
     *
     * @param Customer $customer
     */
    protected function updateCustomerInfo(Customer $customer): void
    {
        $customer->last_known_ip = ip();
        $customer->last_login_at = now();
        $customer->save();
    }

    /**
     * Register the listeners for the subscriber.
     *
     * @param Dispatcher $events
     */
    public function subscribe(Dispatcher $events): void
    {
        $events->listen(
            CustomerLogin::class,
            [CustomerEventSubscriber::class, 'onCustomerLogin']
        );

        $events->listen(
            CustomerLogout::class,
            [CustomerEventSubscriber::class, 'onCustomerLogout']
        );

        $events->listen(
            CustomerRegistered::class,
            [CustomerEventSubscriber::class, 'onCustomerRegistered']
        );
    }
}
