<?php

namespace App\Listeners;

use App\Events\AndroidPushNotification;

class SendAndroidNotification
{

    /**
     * Handle the event.
     */
    public function handle(AndroidPushNotification $event): string|bool
    {
        $server_api_key = config('app.server_api_key');
        $fcm_tokens = $event->fcm_token;
        $title = $event->title;
        $message = $event->message;

        // payload data, it will vary according to requirement

        $data = [
            "registration_ids" => [$fcm_tokens],

            "notification" => [

                "title" => $title,

                "body" => $message,

                "sound" => "default" // required for sound on ios
            ],
        ];

        $dataString = json_encode($data);

        $headers = [
            'Authorization: key=' . $server_api_key,
            'Content-Type: application/json',
        ];

        $ch = curl_init();

        curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $dataString);

        $response = curl_exec($ch);

        curl_close($ch);

        return $response;
    }
}
