<?php

namespace App\Listeners;

use App\Events\VendorAuth;
use App\Models\Vendor;
use Illuminate\Events\Dispatcher;

class VendorEventSubscriber
{
    /**
     * Handle vendor login event.
     *
     * @param VendorAuth $event
     */
    public function onVendorAuth(VendorAuth $event): void
    {
        $this->updateVendorInfo($event->vendor);
    }

    /**
     * Update the vendor's last known ip and last login time.
     *
     * @param Vendor $vendor
     */
    protected function updateVendorInfo(Vendor $vendor): void
    {
        $vendor->last_known_ip = ip();
        $vendor->last_login_at = now();
        $vendor->save();
    }

    /**
     * Register the listeners for the subscriber.
     *
     * @param Dispatcher $events
     */
    public function subscribe(Dispatcher $events): void
    {
        $events->listen(
            VendorAuth::class,
            [VendorEventSubscriber::class, 'onVendorAuth']
        );
    }
}
